pub enum Completion {
Object(ObjectObservation),
Interface(InterfaceObservation),
Call(Box<CallRecord>),
ProtocolFailure(ProtocolError),
StaleResponseRejected(RequestId),
}Expand description
Result of applying a correlated response to the runtime.
Variants
Object(ObjectObservation)
An object observation was updated.
Interface(InterfaceObservation)
An interface observation was updated.
Call(Box<CallRecord>)
An operation reached a terminal outcome.
ProtocolFailure(ProtocolError)
A valid protocol failure was applied to a retrieval observation.
StaleResponseRejected(RequestId)
A superseded response was rejected without mutating current state.